@@ -1,4 +1,4 @@
-"IRT.parm" <-
+`IRT.parm` <-
 function (object, ...) {
     UseMethod("IRT.parm")
 }
