@@ -1,5 +1,5 @@
 `cd.vec` <-
-function (x, f, ..., eps = 1e-03) {
+function (x, f, ..., eps = 1e-04) {
     n <- length(x)
     res <- matrix(0, n, n)
     ex <- pmax(abs(x), 1)
@@ -8,7 +8,7 @@ function (x, f, ..., eps = 1e-03) {
         x1[i] <- x[i] + eps * ex[i]
         x2[i] <- x[i] - eps * ex[i]
         diff.f <- c(f(x1, ...) - f(x2, ...))
-        diff.x <- 2 * max(abs(c(x1[i] - x[i], x2[i] - x[i])))
+        diff.x <- x1[i] - x2[i]
         res[, i] <- diff.f / diff.x
     }
     res
