@@ -7,8 +7,15 @@ function (x, digits = max(3, getOption("digits") - 3), ...) {
     model.sum <- data.frame(log.Lik = x$logLik, AIC = x$AIC, BIC = x$BIC, row.names = "")
     print(model.sum)
     cat("\nCoefficients:\n")
-    coefs <- x$coef
-    print(round(coefs, digits))
+    if (is.null(x$attr)) {
+        print(round(x$coef, digits = digits))
+    } else {
+        dat <- data.frame(x$coef, check.names = FALSE)
+        dat[] <- lapply(dat, round, digits = digits)
+        dat$" " <- rep(x$attr, length.out = nrow(dat))
+        print(dat)
+        if (x$ancr) cat("\n'*' denotes an anchoring item\n\n") else cat("\n'*' denotes a linking item\n\n")
+    }
     cat("\nIntegration:\n")
     cat("method: Gauss-Hermite\n")
     cat("quadrature points:", x$control$GHk, "\n")
