@@ -4,7 +4,7 @@ function (x, digits = max(3, getOption("digits") - 3), ...) {
         stop("Use only with 'tpm' objects.\n")
     cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), "\n\n", sep = "")
     if (is.matrix(coefs <- x$coef)) {
-        coefs <- if (x$IRT.param) IRT.parm(x)$parms else object$coef
+        coefs <- if (x$IRT.param) IRT.parm(x)$parms else x$coef
         coefs[, 1] <- plogis(coefs[, 1]) * x$max.guessing
         p <- length(coefs) - 1
         cat("Coefficients:\n")
