@@ -8,7 +8,7 @@ function (x, digits = max(3, getOption("digits") - 3), ...) {
     cat("\nAlternative hypothesis: the second eigenvalue of the observed data is substantially larger",
         "\n\t\t\tthan the second eigenvalue of data under the assumed IRT model")
     cat("\n\nSecond eigenvalue in the observed data:", round(x$Tobs[2], digits))
-    cat("\nAverage of second eigenvalues in Bootstrap samples:", round(mean(x$T.boot[, 2], na.rm = TRUE), digits))
+    cat("\nAverage of second eigenvalues in Monte Carlo samples:", round(mean(x$T.boot[, 2], na.rm = TRUE), digits))
     cat("\nMonte Carlo samples:", NROW(x$T.boot))
     cat("\np-value:", round(x$p.value, digits))
     cat("\n\n")
